@@ -1,5 +1,6 @@
 import numpy as np
 import colorsys
+import warnings
 
 from .views import Dataview, Volume, Vertex
 from .braindata import VolumeData, VertexData, _hash
@@ -118,6 +119,10 @@ class DataviewRGB(Dataview):
             sdict['vmax'] = [255]
         return sdict
 
+    def get_cmapdict(self):
+        return dict()
+
+
 class VolumeRGB(DataviewRGB):
     """
     Contains RGB (or RGBA) colors for each voxel in a volumetric dataset.
@@ -207,13 +212,18 @@ class VolumeRGB(DataviewRGB):
                 self.red = channel1
                 self.green = channel2
                 self.blue = channel3
+                self.alpha = alpha
             else:  # need to remap colors
-                red, green, blue = VolumeRGB.color_voxels(channel1, channel2, channel3, channel1color, channel2color,
-                                                          channel3color, max_color_value, max_color_saturation,
-                                                          shared_range, shared_vmin, shared_vmax)
+                red, green, blue, alpha = VolumeRGB.color_voxels(
+                    channel1, channel2, channel3,
+                    channel1color, channel2color, channel3color,
+                    max_color_value, max_color_saturation,
+                    shared_range, shared_vmin, shared_vmax, alpha=alpha
+                )
                 self.red = Volume(red, channel1.subject, channel1.xfmname)
                 self.green = Volume(green, channel1.subject, channel1.xfmname)
                 self.blue = Volume(blue, channel1.subject, channel1.xfmname)
+                self.alpha = alpha
         else:
             if subject is None or xfmname is None:
                 raise TypeError("Subject and xfmname are required")
@@ -223,24 +233,18 @@ class VolumeRGB(DataviewRGB):
                 self.red = Volume(channel1, subject, xfmname)
                 self.green = Volume(channel2, subject, xfmname)
                 self.blue = Volume(channel3, subject, xfmname)
-            else:	# need to remap colors
-                red, green, blue = VolumeRGB.color_voxels(channel1, channel2, channel3, channel1color, channel2color,
-                                                          channel3color, max_color_value, max_color_saturation,
-                                                          shared_range, shared_vmin, shared_vmax)
+                self.alpha = alpha
+            else:  # need to remap colors
+                red, green, blue, alpha = VolumeRGB.color_voxels(
+                    channel1, channel2, channel3,
+                    channel1color, channel2color, channel3color,
+                    max_color_value, max_color_saturation,
+                    shared_range, shared_vmin, shared_vmax, alpha=alpha
+                )
                 self.red = Volume(red, subject, xfmname)
                 self.green = Volume(green, subject, xfmname)
                 self.blue = Volume(blue, subject, xfmname)
-
-
-        if alpha is None:
-            alpha = np.ones(self.red.volume.shape)
-            alpha = Volume(alpha, self.red.subject, self.red.xfmname,
-                           vmin=0, vmax=1)
-
-        if not isinstance(alpha, Volume):
-            alpha = Volume(alpha, self.red.subject, self.red.xfmname)
-
-        self.alpha = alpha
+                self.alpha = alpha
 
         if self.red.xfmname == self.green.xfmname == self.blue.xfmname == self.alpha.xfmname:
             self.xfmname = self.red.xfmname
@@ -249,6 +253,32 @@ class VolumeRGB(DataviewRGB):
 
         super(VolumeRGB, self).__init__(subject, alpha, description=description, state=state, **kwargs)
 
+    @property
+    def alpha(self):
+        """Compute alpha transparency"""
+        alpha = self._alpha
+        if alpha is None:
+            alpha = np.ones(self.red.volume.shape)
+            alpha = Volume(alpha, self.red.subject, self.red.xfmname, vmin=0, vmax=1)
+        if not isinstance(alpha, Volume):
+            if alpha.dtype != np.uint8 and (alpha.min() < 0 or alpha.max() > 1):
+                warnings.warn(
+                    "Some alpha values are outside the range of [0, 1]. "
+                    "Consider passing a Volume object as alpha with explicit vmin, vmax "
+                    "keyword arguments.",
+                    Warning
+                )
+            alpha = Volume(alpha, self.red.subject, self.red.xfmname, vmin=0, vmax=1)
+
+        rgb = np.array([self.red.volume, self.green.volume, self.blue.volume])
+        mask = np.isnan(rgb).any(axis=0)
+        alpha.volume[mask] = alpha.vmin
+        return alpha
+
+    @alpha.setter
+    def alpha(self, alpha):
+        self._alpha = alpha
+
     def to_json(self, simple=False):
         sdict = super(VolumeRGB, self).to_json(simple=simple)
         if simple:
@@ -306,7 +336,7 @@ class VolumeRGB(DataviewRGB):
     @staticmethod
     def color_voxels(channel1, channel2, channel3, channel1color, channel2color,
                      channel3Color, value_max, saturation_max, common_range,
-                     common_min, common_max):
+                     common_min, common_max, alpha=None):
         """
         Colors voxels in 3 color dimensions but not necessarily canonical red, green, and blue
         Parameters
@@ -336,25 +366,41 @@ class VolumeRGB(DataviewRGB):
         common_max : float, optional
             Predetermined shared vmax. Does nothing if shared_range == False. If not given,
             will be the 99th percentile of all values across all three channels
+        alpha : ndarray or Volume, optional
+            Alpha values for each voxel. If None, alpha is set to 1 for all voxels. 
 
         Returns
         -------
         red : ndarray of channel1.shape
             uint8 array of red values
-        green : ndarray of data2.shape
+        green : ndarray of channel1.shape
             uint8 array of green values
-        blue : ndarray of data3.shape
+        blue : ndarray of channel1.shape
             uint8 array of blue values
-
+        alpha : ndarray
+            If alpha=None, uint8 array of alpha values with alpha=1 for every voxel. 
+            Otherwise, the same alpha values that were passed in. Additionally, 
+            voxels with NaNs will have an alpha value of 0.
         """
         # normalize each channel to [0, 1]
-        data1 = np.nan_to_num(channel1.data if isinstance(channel1, VolumeData) else channel1).astype(np.float)
-        data2 = np.nan_to_num(channel2.data if isinstance(channel2, VolumeData) else channel2).astype(np.float)
-        data3 = np.nan_to_num(channel3.data if isinstance(channel3, VolumeData) else channel3).astype(np.float)
+        data1 = channel1.data if isinstance(channel1, VolumeData) else channel1
+        data1 = data1.astype(float)
+        data2 = channel2.data if isinstance(channel2, VolumeData) else channel2
+        data2 = data2.astype(float)
+        data3 = channel3.data if isinstance(channel3, VolumeData) else channel3
+        data3 = data3.astype(float)
 
         if (data1.shape != data2.shape) or (data2.shape != data3.shape):
             raise ValueError('Volumes are of different shapes')
 
+        # Create an alpha mask now, before casting nans to 0
+        # Voxels with at least one channel equal to NaN will be masked out.
+        mask = np.isnan(np.array([data1, data2, data3])).any(axis=0)
+        # Now convert to NaNs to num for all channels
+        data1 = np.nan_to_num(data1)
+        data2 = np.nan_to_num(data2)
+        data3 = np.nan_to_num(data3)
+
         if common_range:
             if common_min is None:
                 if common_max is None:
@@ -415,7 +461,12 @@ class VolumeRGB(DataviewRGB):
             green.flat[i] = this_color[1]
             blue.flat[i] = this_color[2]
 
-        return red, green, blue
+        # Now make an alpha volume
+        if alpha is None:
+            alpha = np.ones_like(red, np.uint8) * 255
+        alpha[mask] = 0
+
+        return red, green, blue, alpha
 
 
 class VertexRGB(DataviewRGB):
@@ -476,16 +527,37 @@ class VertexRGB(DataviewRGB):
             self.green = Vertex(green, subject)
             self.blue = Vertex(blue, subject)
 
-        if alpha is None:
-            alpha = np.ones(self.red.vertices.shape)
-            alpha = Vertex(alpha, self.red.subject, vmin=0, vmax=1)
-        if not isinstance(alpha, Vertex):
-            alpha = Vertex(alpha, self.red.subject)
         self.alpha = alpha
 
         super(VertexRGB, self).__init__(subject, alpha, description=description,
                                         state=state, **kwargs)
 
+    @property
+    def alpha(self):
+        """Compute alpha transparency"""
+        alpha = self._alpha
+        if alpha is None:
+            alpha = np.ones(self.red.vertices.shape[1])
+            alpha = Vertex(alpha, self.red.subject, vmin=0, vmax=1)
+        if not isinstance(alpha, Vertex):
+            if alpha.dtype != np.uint8 and (alpha.min() < 0 or alpha.max() > 1):
+                warnings.warn(
+                    "Some alpha values are outside the range of [0, 1]. "
+                    "Consider passing a Vertex object as alpha with explicit vmin, vmax "
+                    "keyword arguments.",
+                    Warning
+                )
+            alpha = Vertex(alpha, self.red.subject, vmin=0, vmax=1)
+
+        rgb = np.array([self.red.data, self.green.data, self.blue.data])
+        mask = np.isnan(rgb).any(axis=0)
+        alpha.data[mask] = alpha.vmin
+        return alpha
+
+    @alpha.setter
+    def alpha(self, alpha):
+        self._alpha = alpha
+
     @property
     def vertices(self):
         """3-dimensional volume (t, v, rgba) with data that has been mapped
