@@ -194,7 +194,7 @@ def import_subj(fs_subject, cx_subject=None, freesurfer_subject_dir=None, whitem
 
     # Freesurfer uses FOV/2 for center, let's set the surfaces to use the
     # magnet isocenter
-    trans = nibabel.load(out).get_affine()[:3, -1]
+    trans = nibabel.load(out).affine[:3, -1]
     surfmove = trans - np.sign(trans) * [128, 128, 128]
 
     from . import formats
@@ -555,7 +555,7 @@ def get_label(cx_subject, label, fs_subject=None, fs_dir=None, src_subject='fsav
             print("Transforming label file to subject's freesurfer directory...")
             _move_labels(fs_subject, label, hemisphere=hemisphere, fs_dir=fs_dir, src_subject=src_subject)
     verts, values = _parse_labels(label_files, cx_subject)
-    idx = verts.astype(np.int)
+    idx = verts.astype(int)
     return idx, values
 
 
