@@ -3,7 +3,7 @@ import numpy as np
 from .. import dataset
 from ..database import db
 from ..options import config
-from .utils import _get_height, _get_extents, _convert_svg_kwargs, _has_cmap, _get_images, _parse_defaults
+from .utils import _get_height, _get_extents, _convert_svg_kwargs, _get_images, _parse_defaults
 from .utils import make_flatmap_image, _make_hatch_image, _get_fig_and_ax, get_flatmask, get_flatcache
 
 
@@ -66,7 +66,7 @@ def add_curvature(fig, dataview, extents=None, height=None, threshold=True, cont
     if default_smoothing.lower()=='none':
         default_smoothing = None
     else:
-        default_smoothing = np.float(default_smoothing)
+        default_smoothing = np.float_(default_smoothing)
     if smooth is None:
         # (Might still be None!)
         smooth = default_smoothing
@@ -98,7 +98,7 @@ def add_curvature(fig, dataview, extents=None, height=None, threshold=True, cont
     if not legacy_mode:
         if use_threshold_curvature:
             # Assumes symmetrical curvature_lims
-            curv_im = (np.nan_to_num(curv_im) > 0.5).astype(np.float)
+            curv_im = (np.nan_to_num(curv_im) > 0.5).astype(float)
             curv_im[np.isnan(curv)] = np.nan
         # Get defaults for brightness, contrast
         if brightness is None:
@@ -162,7 +162,7 @@ def add_data(fig, braindata, height=1024, thick=32, depth=0.5, pixelwise=True,
     im, extents = make_flatmap_image(dataview, recache=recache, pixelwise=pixelwise, sampler=sampler,
                                      height=height, thick=thick, depth=depth, nanmean=nanmean)
     # Check whether dataview has a cmap instance
-    cmapdict = _has_cmap(dataview)
+    cmapdict = dataview.get_cmapdict()
     # Plot
     _, ax = _get_fig_and_ax(fig)
     img = ax.imshow(im,
